@@ -38,7 +38,7 @@ date_names <- function(mon, mon_ab = mon, day, day_ab = day,
 #'   e.g. `"en"` for American English. See `date_names_langs()`
 #'   for a complete list of available locales.
 date_names_lang <- function(language) {
-  stopifnot(is.character(language), length(language) == 1)
+  check_string(language)
 
   symbols <- date_symbols[[language]]
   if (is.null(symbols)) {
